/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CbmCaInputQaMuch.h
/// \date   13.01.2023
/// \brief  QA-task for CA tracking input from MuCh detector (header)
/// \author S.Zharko <s.zharko@gsi.de>


#ifndef CbmCaInputQaMuch_h
#define CbmCaInputQaMuch_h 1

#include "CbmCaInputQaBase.h"

/// A QA-task class, which provides assurance of TOF hits and geometry
///
class CbmCaInputQaMuch : public CbmCaInputQaBase<cbm::algo::ca::EDetectorID::kMuch> {
public:
  /// @brief  Constructor from parameters
  /// @param  verbose   Verbose level
  /// @param  isMCUsed  Flag, whether MC information is available for this task
  CbmCaInputQaMuch(int verbose, bool isMCUsed);

protected:
  /// @brief   Checks results of the QA
  /// @return  Success flag
  bool Check();

  /// @brief Initializes data branches
  InitStatus InitDataBranches();

  /// @brief Initializes canvases
  InitStatus InitCanvases();

  /// @brief Initializes histograms
  InitStatus InitHistograms();

  /// @brief Fills histograms per event or time-slice
  void FillHistograms() { CbmCaInputQaBase::FillHistograms(); }

  /// @brief De-initializes histograms
  void DeInit();

  /// @brief Defines parameters of the task
  void DefineParameters();

  /// @brief Fills histograms per hit
  void FillHistogramsPerHit();

  /// @brief Fills histograms per MC point
  void FillHistogramsPerPoint() {}

private:
  ClassDef(CbmCaInputQaMuch, 0);
};

#endif  // CbmCaInputQaMuch_h
